@@ -1,4 +1,8 @@
-use crate::{error::CustomError, io, BinRead, BinResult, Error, ReadOptions};
+use crate::{
+    error::CustomError,
+    io::{self, Seek, Write},
+    BinRead, BinResult, Error, ReadOptions, WriteOptions,
+};
 #[cfg(not(feature = "std"))]
 use alloc::{boxed::Box, string::String};
 
@@ -65,32 +69,22 @@ where
     }
 }
 
-pub fn try_after_parse<Reader, ValueType, ArgType>(
-    item: &mut Option<ValueType>,
-    reader: &mut Reader,
-    ro: &ReadOptions,
-    args: ArgType,
-) -> BinResult<()>
-where
-    Reader: io::Read + io::Seek,
-    ValueType: BinRead<Args = ArgType>,
-    ArgType: Copy + 'static,
-{
-    if let Some(value) = item.as_mut() {
-        value.after_parse(reader, ro, args)?;
-    }
-
-    Ok(())
-}
-
 pub fn parse_function_args_type_hint<R, Res, Args, F>(_: F, a: Args) -> Args
 where
-    R: crate::io::Read + crate::io::Seek,
+    R: crate::io::Read + Seek,
     F: FnOnce(&mut R, &crate::ReadOptions, Args) -> crate::BinResult<Res>,
 {
     a
 }
 
+pub fn write_function_args_type_hint<T, W, Args, F>(_: F, a: Args) -> Args
+where
+    W: Write + Seek,
+    F: FnOnce(&T, &mut W, &crate::WriteOptions, Args) -> crate::BinResult<()>,
+{
+    a
+}
+
 pub fn map_args_type_hint<Input, Output, MapFn, Args>(_: &MapFn, args: Args) -> Args
 where
     MapFn: FnOnce(Input) -> Output,
@@ -98,3 +92,81 @@ where
 {
     args
 }
+
+pub fn write_fn_type_hint<T, WriterFn, Writer, Args>(x: WriterFn) -> WriterFn
+where
+    Args: Clone,
+    Writer: Write + Seek,
+    WriterFn: Fn(&T, &mut Writer, &WriteOptions, Args) -> BinResult<()>,
+{
+    x
+}
+
+pub fn write_map_args_type_hint<Input, Output, MapFn, Args>(_: &MapFn, args: Args) -> Args
+where
+    MapFn: FnOnce(Input) -> Output,
+    Output: crate::BinWrite<Args = Args>,
+{
+    args
+}
+
+pub fn write_try_map_args_type_hint<Input, Output, MapFn, Args>(_: &MapFn, args: Args) -> Args
+where
+    MapFn: FnOnce(Input) -> BinResult<Output>,
+    Output: crate::BinWrite<Args = Args>,
+{
+    args
+}
+
+pub fn write_map_fn_input_type_hint<Input, Output, MapFn>(func: MapFn) -> MapFn
+where
+    MapFn: FnOnce(Input) -> Output,
+{
+    func
+}
+
+pub fn write_fn_map_output_type_hint<Input, Output, MapFn, Writer, WriteFn, Args>(
+    _: &MapFn,
+    func: WriteFn,
+) -> WriteFn
+where
+    MapFn: FnOnce(Input) -> Output,
+    Args: Clone,
+    Writer: Write + Seek,
+    WriteFn: Fn(&Output, &mut Writer, &WriteOptions, Args) -> BinResult<()>,
+{
+    func
+}
+
+pub fn write_fn_try_map_output_type_hint<Input, Output, MapFn, Writer, WriteFn, Args>(
+    _: &MapFn,
+    func: WriteFn,
+) -> WriteFn
+where
+    MapFn: FnOnce(Input) -> BinResult<Output>,
+    Args: Clone,
+    Writer: Write + Seek,
+    WriteFn: Fn(&Output, &mut Writer, &WriteOptions, Args) -> BinResult<()>,
+{
+    func
+}
+
+pub fn write_zeroes<W: Write>(writer: &mut W, count: u64) -> BinResult<()> {
+    const BUF_SIZE: u64 = 0x20;
+    const ZEROES: [u8; BUF_SIZE as usize] = [0u8; BUF_SIZE as usize];
+
+    if count <= BUF_SIZE {
+        writer.write_all(&ZEROES[..count as usize])?;
+    } else {
+        let full_chunks = count / BUF_SIZE;
+        let remaining = count % BUF_SIZE;
+
+        for _ in 0..full_chunks {
+            writer.write_all(&ZEROES)?;
+        }
+
+        writer.write_all(&ZEROES[..remaining as usize])?;
+    }
+
+    Ok(())
+}
